#ifndef HT16K33_H
#define	HT16K33_H
//------------------------------------------------------------------------------
#include "ht16k33_prototypes.h"
//------------------------------------------------------------------------------
void ht16k33_init()
{     
    I2C_init(100000);            //100 Khz
    
    __delay_ms(5);               //Required after Power On reset to give time to initialize device
   
    ht16k33_on();
    ht16k33_setBrightness(15);   //Valid values from 0 - 15
    ht16k33_blink(0);            //Blink OFF
}
//------------------------------------------------------------------------------
void ht16k33_on()
{
    I2C_start();
    
    I2C_write(HT16K33_ADDRESS);
    I2C_write(OSCILLATOR_ON);          
    
    I2C_stop();
}
//------------------------------------------------------------------------------
void ht16k33_setBrightness(unsigned char num)
{   
   char level = ( num <= 15 ) ? num : 1;  //Default to 1 if invalid value is provided
    
   I2C_start();
   
   I2C_write(HT16K33_ADDRESS);
   I2C_write(DIGITAL_DIM | level);  // Dimming command. valid values are 0 - 15
   
   I2C_stop();
}
//------------------------------------------------------------------------------
void ht16k33_blink(char data)
{
    I2C_start();
    
    I2C_write(HT16K33_ADDRESS);
    I2C_write(DISPLAY_SETUP | (data << 1));  // Blinking / blanking command
    
    I2C_stop();
}
//------------------------------------------------------------------------------
void ht16k33_displayNum(signed int number)
{
    char* text = toString(number);
    
    I2C_start();
    
    I2C_write(HT16K33_ADDRESS);
    I2C_write(DISPLAY_MEMORY);     //Display data start address. Auto increments on every write.
    ht16k33_write(text);
    
    I2C_stop();
}
//------------------------------------------------------------------------------
void ht16k33_write(char text[])
{
  while(*text)
  {
    ht16k33_char(*text++);
  }
}
//------------------------------------------------------------------------------
void ht16k33_char(char asciiChar)
{    
    char digit = getDigit(asciiChar); //ascii to 7 seg

    I2C_write(digit);               //Lower byte  (D7 - D0)
    I2C_write(0);                   //Higher byte (D15 - D8) Unused in 7 seg display
}
//------------------------------------------------------------------------------
char getDigit(char asciiChar)  
{
    char digit = 0;
    
    if(asciiChar >= '0' && asciiChar <= '9')
    {
        char i = asciiChar - '0';
        digit = digits[i];
    }
    else
        if(asciiChar == '-')
        {
            digit = 0x40;  //0x40 - minus symbol
        }
        else
            if(asciiChar == ' ')
            {
                digit = 0x00; //0x00 - blank. used for leading zero suppression
            }
    
    return digit;
}
//------------------------------------------------------------------------------
char* toString(signed int number)
{
  char strNum[10];
  sprintf(strNum,"%4i",number);
  
  return strNum;
}
//------------------------------------------------------------------------------
#endif	/* HT16K33_H */

